PagifyAsyncCallStatus enum

Represents the different states of an asynchronous paginated API call.

Inheritance
Available extensions

Values

initial → const PagifyAsyncCallStatus

The initial state before any request is made.

loading → const PagifyAsyncCallStatus

Indicates that a request is currently loading.

success → const PagifyAsyncCallStatus

Indicates that the request was successful.

makeChangesInList → const PagifyAsyncCallStatus

Indicates that there is changes happens in list.

error → const PagifyAsyncCallStatus

Indicates that an error occurred during the request.

networkError → const PagifyAsyncCallStatus

Indicates that the request failed due to network connectivity issues.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isError → bool

Available on PagifyAsyncCallStatus, provided by the AsyncCallStatusExtension extension

Returns true if the status is PagifyAsyncCallStatus.error.
no setter
isLoading → bool

Available on PagifyAsyncCallStatus, provided by the AsyncCallStatusExtension extension

Returns true if the status is PagifyAsyncCallStatus.loading.
no setter
isNetworkError → bool

Available on PagifyAsyncCallStatus, provided by the AsyncCallStatusExtension extension

Returns true if the status is PagifyAsyncCallStatus.networkError.
no setter
isSuccess → bool

Available on PagifyAsyncCallStatus, provided by the AsyncCallStatusExtension extension

Returns true if the status is PagifyAsyncCallStatus.success.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PagifyAsyncCallStatus>
A constant List of the values in this enum, in order of their declaration.