pagify library

Classes

Pagify<FullResponse, Model>
FullResponse is the type of the API response. Model is the type of each data item in the list.
PagifyController<E>
A controller for managing the data and scroll state of a Pagify widget.
RetainableScrollController
pagify scroll controller
SnapshotHandler
A widget that wraps a StreamBuilder to handle PagifyAsyncCallStatus and render the appropriate UI state (loading, error, or success).

Extensions

NullChecker on Object?
isNull extension to show if this object is null or not
ZeroChecker on num?
ZeroChecker extension to show if this num is zero or not