accessElement method
Returns the element at the given index, or null if out of range.
Implementation
E? accessElement(int index) {
return _items.value.elementAtOrNull(index);
}
Returns the element at the given index, or null if out of range.
E? accessElement(int index) {
return _items.value.elementAtOrNull(index);
}