SnapshotHandler class

A widget that wraps a StreamBuilder to handle PagifyAsyncCallStatus and render the appropriate UI state (loading, error, or success).

Inheritance

Constructors

SnapshotHandler({Key? key, required AsyncSnapshot<PagifyAsyncCallStatus> snapshot, required Widget loadingWidget, required Widget activeStateCallBack(AsyncSnapshot<PagifyAsyncCallStatus> snapshot)})
Creates a snapshot handler for managing async call UI states.
const

Properties

activeStateCallBack Widget Function(AsyncSnapshot<PagifyAsyncCallStatus> snapshot)
Callback to build the active UI state when the stream has data.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget
Widget to display while loading.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot AsyncSnapshot<PagifyAsyncCallStatus>
Snapshot from the StreamBuilder containing pagination state.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited