pagify library
Classes
-
Pagify<
FullResponse, Model> -
FullResponseis the type of the API response.Modelis the type of each data item in the list. -
PagifyController<
E> - A controller for managing the data and scroll state of a Pagify widget.
- RetainableScrollController
- pagify scroll controller
- SnapshotHandler
- A widget that wraps a StreamBuilder to handle PagifyAsyncCallStatus and render the appropriate UI state (loading, error, or success).
Extensions
- NullChecker on Object?
-
isNull extension to show if this
objectis null or not - ZeroChecker on num?
- ZeroChecker extension to show if this num is zero or not